@@ -59,7 +59,7 @@ impl BindingType {
                 min_binding_size: None,
             },
             BindingType::SampledTexture { multisampled } => wgpu::BindingType::Texture {
-                sample_type: wgpu::TextureSampleType::Float { filterable: false },
+                sample_type: wgpu::TextureSampleType::Float { filterable: true },
                 multisampled: *multisampled,
                 view_dimension: wgpu::TextureViewDimension::D2,
             },
